@@ -144,7 +144,16 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup generalConfig(config, "General");
-    QPoint pos = generalConfig.readEntry("Position", QPoint(0, 0));
+
+    const QSize initialSize(424, 187);
+    // split up position and size to be compatible with previous version
+    // that only stored the position.
+    QPoint pos = generalConfig.readEntry("Position", QPoint());
+    if (!pos.isNull()) {
+        QSize size = generalConfig.readEntry("Size", initialSize);
+        mRect = QRect(pos, size);
+        setGeometry(mRect);
+    }
 
     int defSuspendVal = generalConfig.readEntry("DefaultSuspendValue", defSuspendVal);
     int suspendVal = generalConfig.readEntry("SuspendValue", defSuspendVal);
@@ -154,10 +163,6 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
                                                                                defSuspendUnit));
 
     QWidget *topBox = new QWidget(this);
-    if (!pos.isNull()) {
-        mPos = pos;
-        topBox->move(mPos);
-    }
     setWindowTitle(i18nc("@title:window", "Reminders"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("korgac")));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
@@ -202,20 +207,24 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
                                   "Press this button to suspend the currently selected incidences.  "
                                   "The suspend interval is configurable by the Suspend duration settings."));
 
-    // Initial dialog should be rather small.
-    // However, the user can resize and the window geometry is saved/restored.
-    setMinimumWidth(575);
-    setMinimumHeight(300);
-
-    QVBoxLayout *mTopLayout = new QVBoxLayout(topBox);
-    mTopLayout->setMargin(0);
+    QVBoxLayout *topLayout = new QVBoxLayout(topBox);
+    // Try to keep the dialog small and non-obtrusive.
+    // the user can resize down to the minimum
+    setMinimumSize(280, 160);
+    // a more useful size to start with
+    resize(initialSize);
+    // take out some padding which makes it larger
+    topLayout->setSpacing(2);
+    QMargins margins(0, 0, 0, 0);
+    topLayout->setContentsMargins(margins);
+    setContentsMargins(margins);
 
     QLabel *label = new QLabel(
         i18nc("@label",
               "Reminders: "
-              "Click on a title to toggle the details viewer for that item"),
+              "Clicking on the title toggles details for item"),
         topBox);
-    mTopLayout->addWidget(label);
+    topLayout->addWidget(label);
 
     mIncidenceTree = new QTreeWidget(topBox);
     mIncidenceTree->setColumnCount(3);
@@ -240,7 +249,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mIncidenceTree->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mIncidenceTree->setRootIsDecorated(false);
 
-    mTopLayout->addWidget(mIncidenceTree);
+    topLayout->addWidget(mIncidenceTree);
 
     connect(mIncidenceTree, &QTreeWidget::itemClicked, this, &AlarmDialog::update);
     connect(mIncidenceTree, &QTreeWidget::itemDoubleClicked, this, &AlarmDialog::edit);
@@ -251,14 +260,14 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
                              "<emphasis>Select an event or to-do from the list above "
                              "to view its details here.</emphasis>");
     mDetailView->setDefaultMessage(s);
-    mTopLayout->addWidget(mDetailView);
+    topLayout->addWidget(mDetailView);
     mDetailView->hide();
     mLastItem = nullptr;
 
     QWidget *suspendBox = new QWidget(topBox);
     QHBoxLayout *suspendBoxHBoxLayout = new QHBoxLayout(suspendBox);
     suspendBoxHBoxLayout->setMargin(0);
-    mTopLayout->addWidget(suspendBox);
+    topLayout->addWidget(suspendBox);
 
     QLabel *l = new QLabel(i18nc("@label:spinbox", "Suspend &duration:"), suspendBox);
     suspendBoxHBoxLayout->addWidget(l);
@@ -348,7 +357,7 @@ ReminderTreeItem *AlarmDialog::searchByItem(const Akonadi::Item &incidence)
 
 static QString cleanSummary(const QString &summary)
 {
-    static QString etc = i18nc("@label an elipsis", "...");
+    static QString etc = i18nc("@label an ellipsis", "...");
     int maxLen = 30;
     QString retStr = summary;
     retStr.replace(QLatin1Char('\n'), QLatin1Char(' '));
@@ -621,14 +630,19 @@ void AlarmDialog::show()
 //  mSuspendSpin->setValue( defSuspendVal );
 //  mSuspendUnit->setCurrentIndex( defSuspendUnit );
 
-    QDialog::show();
-    if (!mPos.isNull()) {
-        QDialog::move(mPos);
+    // move then show, avoids a visible jump if it is show then move
+    if (!mRect.isNull()) {
+        setGeometry(mRect);
     }
+    QDialog::show();
     KWindowSystem::unminimizeWindow(winId(), false);
     KWindowSystem::setState(winId(), NET::KeepAbove | NET::DemandsAttention);
     KWindowSystem::setOnAllDesktops(winId(), true);
-    KWindowSystem::activateWindow(winId());
+    if (grabFocus()) {
+        KWindowSystem::activateWindow(winId());
+    } else {
+        KWindowSystem::raiseWindow(winId());
+    }
 
     // Audio, Procedure, and EMail alarms
     eventNotification();
@@ -798,7 +812,9 @@ void AlarmDialog::slotSave()
     }
 
     generalConfig.writeEntry("Reminders", numReminders);
-    generalConfig.writeEntry("Position", pos());
+    mRect = geometry();
+    generalConfig.writeEntry("Position", mRect.topLeft());
+    generalConfig.writeEntry("Size", mRect.size());
     generalConfig.writeEntry("DefaultSuspendValue", defSuspendVal);
     generalConfig.writeEntry("DefaultSuspendUnit", defSuspendUnit);
     generalConfig.writeEntry("SuspendValue", mSuspendSpin->value());
@@ -837,10 +853,17 @@ int AlarmDialog::activeCount()
 
 void AlarmDialog::closeEvent(QCloseEvent *)
 {
+    // note, this is on application close (not window hide)
     slotSave();
     accept();
 }
 
+void AlarmDialog::reject()
+{
+    slotSave();
+    QDialog::reject();
+}
+
 void AlarmDialog::updateButtons()
 {
     const ReminderList selection = selectedItems();
@@ -919,7 +942,7 @@ void AlarmDialog::update()
 void AlarmDialog::accept()
 {
     if (activeCount() == 0) {
-        mPos = pos();
+        slotSave();
         hide();
     }
 }
@@ -1101,3 +1124,10 @@ void AlarmDialog::removeFromConfig(const QList<Akonadi::Item::Id> &ids)
     }
     genGroup.sync();
 }
+
+bool AlarmDialog::grabFocus()
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup generalConfig(config, "General");
+    return generalConfig.readEntry("GrabFocus", false);
+}
