@@ -57,8 +57,8 @@ KService::List KOCore::availablePlugins(const QString &type, int version)
 {
     QString constraint;
     if (version >= 0) {
-        constraint =
-            QStringLiteral("[X-KDE-PluginInterfaceVersion] == %1").arg(QString::number(version));
+        constraint
+            = QStringLiteral("[X-KDE-PluginInterfaceVersion] == %1").arg(QString::number(version));
     }
 
     return KServiceTypeTrader::self()->query(type, constraint);
@@ -120,7 +120,8 @@ CalendarSupport::Plugin *KOCore::loadPlugin(const QString &name)
     return nullptr;
 }
 
-EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(const KService::Ptr &service)
+EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(
+    const KService::Ptr &service)
 {
     KPluginLoader loader(*service);
     auto factory = loader.instance();
@@ -169,8 +170,8 @@ KOrg::Part *KOCore::loadPart(const KService::Ptr &service, KOrg::MainWindow *par
         return nullptr;
     }
 
-    KOrg::PartFactory *pluginFactory =
-        static_cast<KOrg::PartFactory *>(factory);
+    KOrg::PartFactory *pluginFactory
+        = static_cast<KOrg::PartFactory *>(factory);
 
     if (!pluginFactory) {
         qCDebug(KORGANIZER_LOG) << "Cast failed";
